#!/bin/sh

# NAME:
#	scm-update.sh - scm agnostic update
#	
# DESCRIPTION:
#	This script hides the details of the SCM being used.
#	Exit status indicates whether anything was updated.
#	
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>

# RCSid:
#	$Id: scm-update.sh,v 1.6 2022/10/05 23:38:10 sjg Exp $
#
#	@(#) Copyright (c) 2016 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

# do nothing if this exists
for f in .nocvs .noscm
do
    test -f $f && exit 2
done

# used for scm's like git/hg
tf=/tmp/su$$

# find out which scm we have
. scm.sh

case "$SCM" in
cvs|svn) # trivial
    CVS_UPDATE_FLAGS=-dP
    
    scm update
    ;;
git)
    GIT=${GIT:-git}
    $GIT fetch $GIT_FETCH_ARGS
    bv=`$GIT branch -v | grep '^\*'`
    case "$bv" in
    *"["*behind*"]"*)
        echo "$bv"
        $GIT stash &&
        $GIT rebase &&
        $GIT stash pop
        ;;
    esac
    $GIT branch -v
    ;;
hg)
    HG=${HG:-hg}            
    $HG pull $HG_PULL_ARGS 2>&1 | tee $tf.pull
    case `egrep "'hg " $tf.pull` in
    *merge*) $HG merge;;
    *update*) $HG update;;
    esac
    ;;
esac > .scm.update 2> .scm.update2
case "$SCM" in
cvs)	grep -q '^U' .scm.update;;
git)	grep -q '^\* .*behind' .scm.update;;
hg)	egrep -q "'hg (merge|update)" .scm.update;;
svn)	grep -q '^[ A-Z]*[ADPU] ' .scm.update;;
esac
rc=$?
rm -f $tf.*
exit $rc
