:
# NAME:
#	upd_sndboot - update secondary named.boot
#
# SYNOPSIS:
#	upd_sndboot.sh ["ndboot" ["dnsaddr"]]
#
# DESCRIPTION:
#	This script reads "ndboot" (default is 'named.boot.new') and
#	outputs a named.boot file suitable for a secondary name
#	server.	 If "dnsaddr" is omitted then the IP address of the
#	current host is used.
#
#	Basically, each 'primary' line in "ndboot" is replaced with a
#	'secondary' line with "dnsaddr" being the address to do zone
#	transfers from.
#
#	We expect "ndboot" to contain a line that includes the words
#	`END OF HEADER' and we do not touch anything above that line.
#	
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>
#

# RCSid:
#	$Id: upd_sndboot.sh,v 1.7 2022/10/10 00:39:06 sjg Exp $
#
#	@(#) Copyright (c) 1994-2022 Simon J. Gerraty.
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

Myname=`basename $0 .sh`
Mydir=`dirname $0`
rc=.${Myname}rc

ndboot=${1-named.boot.new}

for d in . $HOME /etc
do
	test -s $d/$rc && { . $d/$rc; break; }
done

dnsaddr=${2-$dnsaddr}

case "$dnsaddr" in
"")
	myname=`uname -n`
	dnsaddr=`grep $myname /etc/hosts | awk '{ print $1 }' | tail -1`
	;;
esac

TF=/tmp/sndb$$

spacefor.sh /tmp 2048  || { echo $Myname: not enough space /tmp >&2; exit 1; }

cat $ndboot > $TF

cat <<!
; DO NOT EDIT THIS FILE
; it was generated by $0 on `date`
!

# make sure some boiler plate is correct...
ok=`grep 'END OF HEADER' $TF`
case "$ok" in
*END*)
	sed -n '1,/END OF HEADER/p' $TF
	sed '1,/END OF HEADER/d' $TF > $TF.x; mv $TF.x $TF
	;;
*)
	test -s named.cache && ca=cache
	cat <<!
; named.boot
directory	`pwd`
cache	.	named.${ca:-ca}
; we pretend to be a primary root server
primary .	db.root
; every name server is primary for loopback
primary 127.in-addr.arpa named.local
; now for real data...
; END OF HEADER - DO NOT REMOVE THIS LINE
!
	;;
esac

grep 'db\.' $TF | while read line
do
	case "$line" in
	*db.in-addr*)
		file=`echo $line | awk '{ print "hosts/" $2 }'`
		;;
	*in-addr*)
		rev=`echo $line | sed 's,.*[ 	]\([0-9][0-9]*\.[0-9][0-9.]*\).in-.*,\1,'`
		fwd=`IFS=.; set -- $rev; echo $4 $3 $2 $1 | tr ' ' '.'`
		file=rev/$fwd.rev
		;;
	*)
		file=`echo $line | awk '{ print "hosts/" $2 }'`
		;;
	esac
	echo $line | sed -e 's/primary/secondary/' -e "s,db\..*,$dnsaddr $file,"
done

# now do the rest
egrep -i '^(secondary|primary)' $TF | egrep -v 'db\.|named\.' |
	sed -e "/^primary/s,^\([^.][^.]*\.[^ 	]*[ 	][ 	]*\),\1 $dnsaddr ," -e 's/primary/secondary/' -e 's/\.[ 	]*$//'

rm -f $TF 
